---
title: Resolving zsh bus error with erlang/elixir on Mac Sonoma with asdf
date: 2023-11-27
---
A perfect storm of tooling hit me with a difficult to decipher error this morning `zsh bus error mix`. [Others seem to have had similar woes](https://elixirforum.com/t/bus-error-after-upgrading-to-sonoma-beta/56354/41) and I was able to decipher a clean reproducible solution.

The tooling needed to run into this issue:

- Mac upgraded to Sonoma
- Using `asdf` to manage `erlang` and `elixir`
- Using `zsh`

```sh
# upgrade some system dependencies, and asdf itself
brew update
brew upgrade # mostly to update asdf, can target specifically with `brew upgrade asdf` instead

# remove existing erlang and elixir installs, reshimming won't cut it so let's start fresh it doesn't take long
asdf plugin-remove erlang
asdf plugin-remove elixir

# reinstall those plugins
asdf plugin add erlang [https://github.com/asdf-vm/asdf-erlang.git](https://github.com/asdf-vm/asdf-erlang.git)
asdf plugin-add elixir [https://github.com/asdf-vm/asdf-elixir.git](https://github.com/asdf-vm/asdf-elixir.git)

# now let's install the versions App needs of erlang and elixir
cd ./where-my-repos-are/app
export KERL_CONFIGURE_OPTIONS="--disable-debug --without-javac" # recommended step by asdf erlang's readme
asdf install # pulls from app's `.tool-versions` file

# done! try it out
mix deps.get
```